PDFViewer = function(viewerUrl) {
	'use strict';
	var _path = typeof viewerUrl !== 'undefined' ? viewerUrl : 'web/viewer.html';
	var _window = window;
	var _view = null;
	var _data;
	var _expires;
	/*
	 * Converteer een base64 encoded string naar een unsigned array of shorts.
	 * Deze functie kan nog worden geoptimaliseerd door atob niet te gebruiken en direct de uint te berekenen van de hex codering
	 */
	function _convert(base64string) {
	  var raw = atob(base64string);
	  var data = new Uint8Array(raw.length);
	  for (var i=0; i<raw.length; i++) {
		data[i] = raw.charCodeAt(i);
	  }
	  return data;
	}
	/*
	 * Laad de pdf in de viewer
	 */
	function _laad() {
		if (typeof _view === 'undefined') {
			throw "No PDFViewer";
		} else if (Date.now()>_expires) {
			throw "Could not load PDFViewer";
		} else if (typeof _view.PDFViewerApplication === 'undefined') {
			setTimeout( function() { _laad() },100);
		} else {
			_view.PDFViewerApplication.open(_data,0);
		}
	}
	
	function _close() {
		_data = null;
		_view = null;
	}
	/*
	 * Open de viewer
	 */ 
	this.open = function() {
		if (typeof _view === 'undefined' || _view == null) {
			_view = _window.open(_path);
			_view.window.onbeforeunload = function () {
				_close();
			}
		} else {
			_view.window.focus();
		}
	}
	/**
	 * Sluit de viewer
	 */ 
	this.close = function() {
		if (typeof _view !== 'undefined' && _view != null) {
			_view.window.close();
		}
	}
	/*
	 * Toon de base64 encoded PDF in de viewer
	 */
	this.show = function(base64encodedPDF) {
		this.open();
		_expires = Date.now() + 10000;
		_data = _convert(base64encodedPDF);
		_laad();
	}
	/*
	 * Toon de base64 encoded PDF in de viewer
	 */
	this.load = function(raw) {
		this.open();
		_expires = Date.now() + 10000;
		_data = raw;
		_laad();
	}
}